<?php

class OrderTransaction {
    private $conn;

    // Constructor to accept a PDO connection
    public function __construct($dbConnection) {
        $this->conn = $dbConnection;
    }

    public function getRecordQuery($tran_id) {
        $sql = "SELECT * FROM student_payment WHERE transaction_id = :tran_id";
        $stmt = $this->conn->prepare($sql);
        $stmt->bindParam(':tran_id', $tran_id);
        $stmt->execute();
        return $stmt->fetch(PDO::FETCH_ASSOC); // Fetch the result as an associative array
    }

    public function saveTransactionQuery($post_data) {
        $sql = "INSERT INTO student_payment (name, email, phone, amount, courseName, courseFee, discount, discountedAmount, paymentMethod, address, status, transaction_id, currency)
                VALUES (:name, :email, :phone, :amount, :courseName, :courseFee, :discount, :discountedAmount, :paymentMethod, :address, 'Pending', :transaction_id, :currency)";

        return $sql; // Return the SQL statement
    }

    public function executeSaveTransaction($post_data, $orderId) {
        $sql = $this->saveTransactionQuery($post_data);
        $stmt = $this->conn->prepare($sql);

        // Bind parameters
        $stmt->bindParam(':name', $post_data['cus_name']);
        $stmt->bindParam(':email', $post_data['cus_email']);
        $stmt->bindParam(':phone', $post_data['cus_phone']);
        $stmt->bindParam(':amount', $post_data['total_amount']);
        $stmt->bindParam(':courseName', $post_data['courseName']);
        $stmt->bindParam(':courseFee', $post_data['courseFee']);
        $stmt->bindParam(':discount', $post_data['discount']);
        $stmt->bindParam(':discountedAmount', $post_data['discountedAmount']);
        $stmt->bindParam(':paymentMethod', $post_data['paymentMethod']);
        $stmt->bindParam(':address', $post_data['cus_add1']);
        $stmt->bindParam(':transaction_id', $orderId);
        $stmt->bindParam(':currency', $post_data['currency'] ?? 'BDT'); // Default to BDT if not set

        // Execute the statement and log any errors
    if (!$stmt->execute()) {
        error_log(print_r($stmt->errorInfo(), true)); // Log the error details
        return false; // Indicate failure
    }

    return true;
    }

    public function updateTransactionQuery($tran_id, $type = 'Success') {
        $sql = "UPDATE student_payment SET status = :type WHERE transaction_id = :tran_id";
        
        $stmt = $this->conn->prepare($sql);
        $stmt->bindParam(':type', $type);
        $stmt->bindParam(':tran_id', $tran_id);
        
        return $stmt->execute(); // Execute the update
    }
}